# Quarterly Sales Report

The following tables summarize our Q3 performance across all regions.

## Regional Revenue

|Region|Q1 Revenue|Q2 Revenue|Q3 Revenue|Growth Rate|
|---|---|---|---|---|
|North America|1250000|1340000 |1520000|12.5|
| Europe|980000|1010000|1105000 | 9.4|
|Asia Pacific |750000| 820000|  935000|14.0|
|Latin America|320000|345000|  398000|15.4 |
|Middle East|210000| 228000| 265000|16.2|

Regional revenue shows strong growth particularly in emerging markets.

## Employee Performance Metrics

| Employee Name|Department|Tasks Completed|Avg Score| Hours Logged|
| ---|---|---| ---|---|
| Sarah Chen |Engineering| 47|92.5|168|
|Marcus Johnson|  Marketing |38 |88.3| 155 |
|  Aisha Patel|Engineering |52|95.1 |172|
| David Kim| Sales|41|  87.6|161|
|Elena Rodriguez |Marketing|  35| 91.2|149|
|James O'Brien|  Sales| 44 |89.8|  158|
| Yuki Tanaka |Engineering|49|93.7| 170|
|Fatima Al-Hassan|  Sales |  46|90.5|163 |

## Product Inventory

|SKU|Product Name|Category|Stock|Unit Price|Total Value|
|--- |--- | ---|---|---|  ---|
|WDG-001| Premium Widget|Widgets|  1500|24.99|37485.00|
|WDG-002|Standard Widget |Widgets|3200 |12.49| 39968.00|
|GDG-001|  Deluxe Gadget|Gadgets| 800|  89.99|71992.00|
| GDG-002|Basic Gadget|Gadgets|2100|34.99 |73479.00|
|SPR-001|  Super Sprocket |Sprockets|4500|  8.99|40455.00|
|SPR-002|Mini Sprocket|Sprockets| 6200| 4.49|27838.00|
|ACC-001 |Universal Adapter|Accessories|  1800|15.99| 28782.00|
|ACC-002|  Travel Adapter |Accessories|2400| 19.99|47976.00 |

All inventory values are current as of the end of Q3.
